Welcome to debian_inspector's documentation!
============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme_link
   API<api/modules>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
